---
name: Configuration Format Changes
about: Suggestions to enhance Padricks Configuration File format
title: ''
labels: configuration format
assignees: ''

---

**Suggested Change**

Describe the suggested change of config format..

**Example snippet**
``` yaml
...
my_awesome_new_kez: value_xy # An example of the changed format in action new key
```
**How this will affect Padricks behavior**
Describe how the change is supposed to affect the behavior of Padrick

**Justification for the change**
Describe why the changes are desirable

**Backwards Compatibility**
Are the changes implementable in a manner that is backwards compatible with the existing format?
